@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for ssm service client
 
@@ -10,15 +11,17 @@ Usage::
     client: SSMClient = boto3.client("ssm")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
+from datetime import datetime
+from typing import Any, Dict, List, Type, overload
+
 from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_ssm.paginator import (
     DescribeActivationsPaginator,
-    DescribeAssociationExecutionTargetsPaginator,
     DescribeAssociationExecutionsPaginator,
+    DescribeAssociationExecutionTargetsPaginator,
     DescribeAutomationExecutionsPaginator,
     DescribeAutomationStepExecutionsPaginator,
     DescribeAvailablePatchesPaginator,
@@ -26,18 +29,18 @@ from mypy_boto3_ssm.paginator import (
     DescribeEffectivePatchesForPatchBaselinePaginator,
     DescribeInstanceAssociationsStatusPaginator,
     DescribeInstanceInformationPaginator,
+    DescribeInstancePatchesPaginator,
     DescribeInstancePatchStatesForPatchGroupPaginator,
     DescribeInstancePatchStatesPaginator,
-    DescribeInstancePatchesPaginator,
     DescribeInventoryDeletionsPaginator,
+    DescribeMaintenanceWindowExecutionsPaginator,
     DescribeMaintenanceWindowExecutionTaskInvocationsPaginator,
     DescribeMaintenanceWindowExecutionTasksPaginator,
-    DescribeMaintenanceWindowExecutionsPaginator,
     DescribeMaintenanceWindowSchedulePaginator,
-    DescribeMaintenanceWindowTargetsPaginator,
-    DescribeMaintenanceWindowTasksPaginator,
     DescribeMaintenanceWindowsForTargetPaginator,
     DescribeMaintenanceWindowsPaginator,
+    DescribeMaintenanceWindowTargetsPaginator,
+    DescribeMaintenanceWindowTasksPaginator,
     DescribeParametersPaginator,
     DescribePatchBaselinesPaginator,
     DescribePatchGroupsPaginator,
@@ -46,14 +49,14 @@ from mypy_boto3_ssm.paginator import (
     GetInventorySchemaPaginator,
     GetParameterHistoryPaginator,
     GetParametersByPathPaginator,
-    ListAssociationVersionsPaginator,
     ListAssociationsPaginator,
+    ListAssociationVersionsPaginator,
     ListCommandInvocationsPaginator,
     ListCommandsPaginator,
     ListComplianceItemsPaginator,
     ListComplianceSummariesPaginator,
-    ListDocumentVersionsPaginator,
     ListDocumentsPaginator,
+    ListDocumentVersionsPaginator,
     ListResourceComplianceSummariesPaginator,
     ListResourceDataSyncPaginator,
 )
@@ -87,8 +90,8 @@ from mypy_boto3_ssm.type_defs import (
     DeregisterTaskFromMaintenanceWindowResultTypeDef,
     DescribeActivationsFilterTypeDef,
     DescribeActivationsResultTypeDef,
-    DescribeAssociationExecutionTargetsResultTypeDef,
     DescribeAssociationExecutionsResultTypeDef,
+    DescribeAssociationExecutionTargetsResultTypeDef,
     DescribeAssociationResultTypeDef,
     DescribeAutomationExecutionsResultTypeDef,
     DescribeAutomationStepExecutionsResultTypeDef,
@@ -99,23 +102,23 @@ from mypy_boto3_ssm.type_defs import (
     DescribeEffectivePatchesForPatchBaselineResultTypeDef,
     DescribeInstanceAssociationsStatusResultTypeDef,
     DescribeInstanceInformationResultTypeDef,
+    DescribeInstancePatchesResultTypeDef,
     DescribeInstancePatchStatesForPatchGroupResultTypeDef,
     DescribeInstancePatchStatesResultTypeDef,
-    DescribeInstancePatchesResultTypeDef,
     DescribeInventoryDeletionsResultTypeDef,
+    DescribeMaintenanceWindowExecutionsResultTypeDef,
     DescribeMaintenanceWindowExecutionTaskInvocationsResultTypeDef,
     DescribeMaintenanceWindowExecutionTasksResultTypeDef,
-    DescribeMaintenanceWindowExecutionsResultTypeDef,
     DescribeMaintenanceWindowScheduleResultTypeDef,
-    DescribeMaintenanceWindowTargetsResultTypeDef,
-    DescribeMaintenanceWindowTasksResultTypeDef,
     DescribeMaintenanceWindowsForTargetResultTypeDef,
     DescribeMaintenanceWindowsResultTypeDef,
+    DescribeMaintenanceWindowTargetsResultTypeDef,
+    DescribeMaintenanceWindowTasksResultTypeDef,
     DescribeOpsItemsResponseTypeDef,
     DescribeParametersResultTypeDef,
     DescribePatchBaselinesResultTypeDef,
-    DescribePatchGroupStateResultTypeDef,
     DescribePatchGroupsResultTypeDef,
+    DescribePatchGroupStateResultTypeDef,
     DescribePatchPropertiesResultTypeDef,
     DescribeSessionsResponseTypeDef,
     DocumentFilterTypeDef,
@@ -148,18 +151,17 @@ from mypy_boto3_ssm.type_defs import (
     InstanceInformationFilterTypeDef,
     InstanceInformationStringFilterTypeDef,
     InstancePatchStateFilterTypeDef,
-    InventoryAggregatorTypeDef,
     InventoryFilterTypeDef,
     InventoryItemTypeDef,
     LabelParameterVersionResultTypeDef,
-    ListAssociationVersionsResultTypeDef,
     ListAssociationsResultTypeDef,
+    ListAssociationVersionsResultTypeDef,
     ListCommandInvocationsResultTypeDef,
     ListCommandsResultTypeDef,
     ListComplianceItemsResultTypeDef,
     ListComplianceSummariesResultTypeDef,
-    ListDocumentVersionsResultTypeDef,
     ListDocumentsResultTypeDef,
+    ListDocumentVersionsResultTypeDef,
     ListInventoryEntriesResultTypeDef,
     ListResourceComplianceSummariesResultTypeDef,
     ListResourceDataSyncResultTypeDef,
@@ -169,14 +171,13 @@ from mypy_boto3_ssm.type_defs import (
     MaintenanceWindowTaskInvocationParametersTypeDef,
     MaintenanceWindowTaskParameterValueExpressionTypeDef,
     NotificationConfigTypeDef,
-    OpsAggregatorTypeDef,
     OpsFilterTypeDef,
     OpsItemDataValueTypeDef,
     OpsItemFilterTypeDef,
     OpsItemNotificationTypeDef,
     OpsResultAttributeTypeDef,
-    ParameterStringFilterTypeDef,
     ParametersFilterTypeDef,
+    ParameterStringFilterTypeDef,
     PatchFilterGroupTypeDef,
     PatchOrchestratorFilterTypeDef,
     PatchRuleGroupTypeDef,
@@ -1010,7 +1011,7 @@ class SSMClient:
     def get_inventory(
         self,
         Filters: List["InventoryFilterTypeDef"] = None,
-        Aggregators: List["InventoryAggregatorTypeDef"] = None,
+        Aggregators: List[Dict[str, Any]] = None,
         ResultAttributes: List[ResultAttributeTypeDef] = None,
         NextToken: str = None,
         MaxResults: int = None,
@@ -1073,7 +1074,7 @@ class SSMClient:
         self,
         SyncName: str = None,
         Filters: List["OpsFilterTypeDef"] = None,
-        Aggregators: List["OpsAggregatorTypeDef"] = None,
+        Aggregators: List[Dict[str, Any]] = None,
         ResultAttributes: List[OpsResultAttributeTypeDef] = None,
         NextToken: str = None,
         MaxResults: int = None,
@@ -1954,3 +1955,6 @@ class SSMClient:
         """
         [Paginator.ListResourceDataSync documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ssm.html#SSM.Paginator.ListResourceDataSync)
         """
+
+    def get_paginator(self, operation_name: str) -> Boto3Paginator:
+        pass
