@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for ssm service client paginators.
 
@@ -94,10 +95,11 @@ Usage::
     list_resource_data_sync_paginator: ListResourceDataSyncPaginator = client.get_paginator("list_resource_data_sync")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Any, Dict, Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_ssm.type_defs import (
     AssociationExecutionFilterTypeDef,
     AssociationExecutionTargetsFilterTypeDef,
@@ -107,8 +109,8 @@ from mypy_boto3_ssm.type_defs import (
     ComplianceStringFilterTypeDef,
     DescribeActivationsFilterTypeDef,
     DescribeActivationsResultTypeDef,
-    DescribeAssociationExecutionTargetsResultTypeDef,
     DescribeAssociationExecutionsResultTypeDef,
+    DescribeAssociationExecutionTargetsResultTypeDef,
     DescribeAutomationExecutionsResultTypeDef,
     DescribeAutomationStepExecutionsResultTypeDef,
     DescribeAvailablePatchesResultTypeDef,
@@ -116,18 +118,18 @@ from mypy_boto3_ssm.type_defs import (
     DescribeEffectivePatchesForPatchBaselineResultTypeDef,
     DescribeInstanceAssociationsStatusResultTypeDef,
     DescribeInstanceInformationResultTypeDef,
+    DescribeInstancePatchesResultTypeDef,
     DescribeInstancePatchStatesForPatchGroupResultTypeDef,
     DescribeInstancePatchStatesResultTypeDef,
-    DescribeInstancePatchesResultTypeDef,
     DescribeInventoryDeletionsResultTypeDef,
+    DescribeMaintenanceWindowExecutionsResultTypeDef,
     DescribeMaintenanceWindowExecutionTaskInvocationsResultTypeDef,
     DescribeMaintenanceWindowExecutionTasksResultTypeDef,
-    DescribeMaintenanceWindowExecutionsResultTypeDef,
     DescribeMaintenanceWindowScheduleResultTypeDef,
-    DescribeMaintenanceWindowTargetsResultTypeDef,
-    DescribeMaintenanceWindowTasksResultTypeDef,
     DescribeMaintenanceWindowsForTargetResultTypeDef,
     DescribeMaintenanceWindowsResultTypeDef,
+    DescribeMaintenanceWindowTargetsResultTypeDef,
+    DescribeMaintenanceWindowTasksResultTypeDef,
     DescribeParametersResultTypeDef,
     DescribePatchBaselinesResultTypeDef,
     DescribePatchGroupsResultTypeDef,
@@ -141,22 +143,21 @@ from mypy_boto3_ssm.type_defs import (
     InstanceInformationFilterTypeDef,
     InstanceInformationStringFilterTypeDef,
     InstancePatchStateFilterTypeDef,
-    InventoryAggregatorTypeDef,
     InventoryFilterTypeDef,
-    ListAssociationVersionsResultTypeDef,
     ListAssociationsResultTypeDef,
+    ListAssociationVersionsResultTypeDef,
     ListCommandInvocationsResultTypeDef,
     ListCommandsResultTypeDef,
     ListComplianceItemsResultTypeDef,
     ListComplianceSummariesResultTypeDef,
-    ListDocumentVersionsResultTypeDef,
     ListDocumentsResultTypeDef,
+    ListDocumentVersionsResultTypeDef,
     ListResourceComplianceSummariesResultTypeDef,
     ListResourceDataSyncResultTypeDef,
     MaintenanceWindowFilterTypeDef,
     PaginatorConfigTypeDef,
-    ParameterStringFilterTypeDef,
     ParametersFilterTypeDef,
+    ParameterStringFilterTypeDef,
     PatchOrchestratorFilterTypeDef,
     ResultAttributeTypeDef,
     SessionFilterTypeDef,
@@ -622,7 +623,7 @@ class GetInventoryPaginator(Boto3Paginator):
     def paginate(
         self,
         Filters: List["InventoryFilterTypeDef"] = None,
-        Aggregators: List["InventoryAggregatorTypeDef"] = None,
+        Aggregators: List[Dict[str, Any]] = None,
         ResultAttributes: List[ResultAttributeTypeDef] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetInventoryResultTypeDef]:
